# Moment-Book

# INTRODUCTION

This is a Python-Sql Project to manage various events with dates. There are various events in life we can’t remember the dates of. This program got the job done for you. From your friend’s birthday date to your mathematics exam date, get to know everything in a second. Save every moment of your life using this program like a notepad and even after years, you can get the date when you got your first salary or any special moment in your life. This Project allows you to edit/modify or delete the records which makes this project even more versatile.

![alt text](https://cdn.discordapp.com/attachments/838392313343901698/932573381054849055/unknown.png)

# Aim and Objective

The main aim of the Moment Book is to create a database for the users where every bit of information related to events that happened in the past ,present or future will be saved. This allows users to be more precise with every moment in their life.

The whole objective of this program is to get the event name with a particular date, that information will then be stored in a database which we can access later on to do stuff like :

- Accessing the data at any time in future.
- Sorting the data.
- Updating the data at any time.
- Deleting records from the data as well

# Languages, Libraries, and Modules Used

## Languages:

This project is based on the following languages:
- Python
- SQL

The RDBMS used, here, to manage and access data is MySQL.

## Libraries:

The libraries used in this project are listed below:
- Pygame Library

## Modules:

The modules used in this project are listed below:

- DateTime
- MySQL Connector

# Diagrammatic Representation

![alt text](https://cdn.discordapp.com/attachments/838392313343901698/932604474848051261/unknown.png)

# Benefits

The Benefits of this project are :

- Writing stuff in diaries is a bit boring nowadays, this project makes it easier as a decent amount of people enjoy typing more than writing manually.

- Now Since we are typing, it saves time and also reduces the wastage of paper.

- Whatever you saved in the moment book, can be viewed or modified anytime after that which makes the program even more versatile.


### Thank you!
